@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,25 +24,29 @@
 #include <glib.h>
 #include <gio/gio.h>
 
+#include <libtracker-data/tracker-data-update.h>
+
 G_BEGIN_DECLS
 
 #if !defined (__LIBTRACKER_DATA_INSIDE__) && !defined (TRACKER_COMPILATION)
 #error "only <libtracker-data/tracker-data.h> must be included directly."
 #endif
 
+#define TRACKER_DATA_BACKUP_ERROR_DOMAIN "TrackerBackup"
+#define TRACKER_DATA_BACKUP_ERROR        tracker_data_backup_error_quark()
+
 typedef void (*TrackerDataBackupFinished) (GError *error, gpointer user_data);
 
 GQuark tracker_data_backup_error_quark (void);
 void   tracker_data_backup_save        (GFile                     *destination,
-                                        GFile                     *journal,
-                                        TrackerDataBackupFinished  callback,
-                                        gpointer                   user_data,
-                                        GDestroyNotify             destroy);
-void   tracker_data_backup_restore     (GFile                     *backup,
-                                        GFile                     *journal,
                                         TrackerDataBackupFinished  callback,
                                         gpointer                   user_data,
                                         GDestroyNotify             destroy);
+void   tracker_data_backup_restore     (GFile                     *journal,
+                                        const gchar              **test_schema,
+                                        TrackerBusyCallback        busy_callback,
+                                        gpointer                   busy_user_data,
+                                        GError                   **error);
 
 G_END_DECLS
 
