@@ -78,7 +78,7 @@ void     tracker_data_notify_transaction            (gboolean
 void     tracker_data_rollback_transaction          (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
                                                      GError                   **error);
-GPtrArray *
+GVariant *
          tracker_data_update_sparql_blank           (const gchar               *update,
                                                      GError                   **error);
 void     tracker_data_update_buffer_flush           (GError                   **error);
@@ -89,7 +89,8 @@ void     tracker_data_load_turtle_file              (GFile                     *
 void     tracker_data_sync                          (void);
 void     tracker_data_replay_journal                (TrackerBusyCallback        busy_callback,
                                                      gpointer                   busy_user_data,
-                                                     const gchar               *busy_status);
+                                                     const gchar               *busy_status,
+                                                     GError                   **error);
 
 /* Calling back */
 void     tracker_data_add_insert_statement_callback      (TrackerStatementCallback   callback,
