@@ -256,7 +256,7 @@ class ExtractorHelper ():
         nao:hasTag [a nao:Tag; nao:prefLabel "xxx"]
                  -> nao:hasTag:prefLabel "xxx"
                  
-        slo:location [a slo:GeoPoint; slo:postalAddress <urn:uuid:1231-123> .]
+        slo:location [a slo:GeoLocation; slo:postalAddress <urn:uuid:1231-123> .]
                 -> slo:location <urn:uuid:1231-123> 
                 
         nfo:hasMediaFileListEntry [ a nfo:MediaFileListEntry ; nfo:entryUrl "file://x.mp3"; nfo:listPosition 1]
@@ -266,7 +266,7 @@ class ExtractorHelper ():
         
         # hasTag case
         if line.startswith ("nao:hasTag"):
-            getlabel = re.compile ("nao:prefLabel\ \"(\w+)\"")
+            getlabel = re.compile ("nao:prefLabel\ \"([\w\ -]+)\"")
             match = getlabel.search (line)
             if (match):
                 line = 'nao:hasTag:prefLabel "%s" ;' % (match.group(1))
@@ -290,7 +290,7 @@ class ExtractorHelper ():
 
             return results
         elif line.startswith ("nco:creator"):
-            getcreator = re.compile ("nco:fullname\ \"(\w+)\"")
+            getcreator = re.compile ("nco:fullname\ \"([\w\ ]+)\"")
             creator_match = getcreator.search (line)
 
             if (creator_match):
